from .options import *

from mongoadmin.sites import site

from django.conf import settings

if getattr(settings, 'MONGOADMIN_OVERRIDE_ADMIN', False):
    import django.contrib.admin
    # copy already registered model admins
    # without that the already registered models
    # don't show up in the new admin
    site._registry = django.contrib.admin.site._registry
    
    django.contrib.admin.site = site 